## 中文自然语言转CRON

pip install nlp2cron

```python
from nlp2cron import nlp2cron
cron = nlp2cron("每天10点25分叫我去买菜")

```

你会得到一个`cron`表达式. 目前代码写的有点乱, 但只要不太随意的自然语言都可以解决
代码里面有一些例子, 详细看代码啦. 代码写的比较随意, 如果要求高请不要用啦.

